@@ -6,7 +6,7 @@ use warnings;
 use List::Util qw(sum);
 use Carp;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 =head1 NAME
@@ -73,6 +73,7 @@ sub new {
 		}
 		elsif ($self->{'module'} eq "ImageMagick" || $self->{'module'} eq "Image::Magick") {
 			require Image::Magick;
+			$self->{'module'} = 'ImageMagick';
 		}
 		elsif ($self->{'module'} eq "Imager") {
 			require Imager;
@@ -145,7 +146,7 @@ sub new {
 # Borrowed from http://www.perlmonks.org/index.pl?node_id=644225
 sub b2h {
     my $num   = shift;
-    my $WIDTH = 32;
+    my $WIDTH = 4;
     my $index = length($num) - $WIDTH;
     my $hex = '';
     do {
@@ -471,6 +472,47 @@ sub phash {
 	}
 }
 
+=head1 HELPER
+
+=head2 greytones
+
+  $ihash->greytones();
+  $ihash->greytones('geometry' => '8x8');
+
+Return the number of different shades of grey after the image are converted to grey tones. The number of shades can be used to indicate the complexity of an image, and exclude images that has a very low complexity.
+
+For example, all images with only a single color will be reduced to an image with a single grey color and thus give the same hash.
+
+=cut
+sub greytones {
+	my ($self, %opt) = @_;
+
+	$opt{'geometry'} ||= '8x8';
+	$opt{'im'} ||= 'im_' . $opt{'geometry'};
+
+	if(!$self->{ $opt{'im'} }) {
+		$self->{'reduse'}->($self, %opt );
+	}
+
+	my @pixels = $self->{'pixels'}->($self, %opt );
+	
+	# aHash specific code
+	
+	# Find the mean values of all the values in the array
+	my $m = sum(@pixels)/@pixels; 
+
+	my %seen;
+	my $count = 0;
+	foreach my $p (@pixels) {
+		if ($seen{$p}) {next;}
+		$seen{$p} = 1;
+		$count++;
+
+	}
+	
+	return $count;
+}
+
 =head1 DEBUGGING
 
 Functions useful for debug purposes. 
